package users

import (
	db "ttime/internal/database"

	"github.com/gofiber/fiber/v2"
	"github.com/gofiber/fiber/v2/log"
)

// ListAllUsers is a handler that returns a list of all users in the application database
// @Summary		ListsAllUsers
// @Description	lists all users
// @Tags			User
// @Accept			json
// @Produce		plain
// @Success		200	{json}		json	"Successfully signed token for user"
// @Failure		401	{string}	string	"Unauthorized"
// @Failure		500	{string}	string	"Internal server error"
// @Router			/users/all [get]
func ListAllUsers(c *fiber.Ctx) error {
	// Get all users from the database
	users, err := db.GetDb(c).GetAllUsersApplication()
	if err != nil {
		log.Info("Error getting users from db:", err) // Debug print
		return c.Status(500).SendString(err.Error())
	}

	log.Info("Returning all users")
	// Return the list of users as JSON
	return c.JSON(users)
}
